@@ -59,8 +59,9 @@ public:
     CGDK2,
     CGH1,
     JQJCY01YM,
-    IBSTH1,
-    IBSTH2,
+    IBSTHBP01B,
+    IBT_2X,
+    IBT_2XS,
     IBT4XS,
     IBT6XS_SOLIS,
     MIBAND,
@@ -80,17 +81,18 @@ public:
     MOKOBEACON,
     MOKOBEACONXPRO,
     INODEEM,
-    IBT_2X,
     RUUVITAG_RAWV1,
     RUUVITAG_RAWV2,
     SBCS,
     SBCU,
+    SBCU_NEW,
     SBMS,
     SBMT,
     SBS1,
     SHT4X,
     SCD4X,
     SMARTDRY,
+    BC08,
     BM1IN1,
     BM3IN1,
     BM4IN1,
@@ -110,6 +112,7 @@ public:
     T301,
     IBEACON,
     SERVICE_DATA,
+    JHT_F525,
     BLE_ID_MAX
   };
 
@@ -123,7 +126,7 @@ private:
   bool        evaluateDatalength(std::string op, size_t data_len, size_t req_len);
   bool        checkPropCondition(const JsonArray& prop, const char* svc_data, const char* mfg_data);
   bool        checkDeviceMatch(const JsonArray& condition, const char* svc_data, const char* mfg_data,
-                               const char* dev_name, const char* svc_uuid);
+                               const char* dev_name, const char* svc_uuid, const char* mac_id);
   std::string sanitizeJsonKey(const char* key_in);
 
   size_t m_docMax = 12000;
