@@ -34,8 +34,7 @@
 #include "devices/H5106_json.h"
 #include "devices/HHCCJCY01HHCC_json.h"
 #include "devices/HHCCPOT002_json.h"
-#include "devices/IBS_TH1_json.h"
-#include "devices/IBS_TH2_json.h"
+#include "devices/IBS_THBP01B_json.h"
 #include "devices/IBT_2X_json.h"
 #include "devices/IBT_4XS_json.h"
 #include "devices/IBT_6XS_SOLIS6_json.h"
@@ -72,6 +71,7 @@
 #include "devices/T301_json.h"
 #include "devices/iBeacon_json.h"
 #include "devices/iNodeEM_json.h"
+#include "devices/BC08_json.h"
 #include "devices/BM1IN1_json.h"
 #include "devices/BM3IN1_json.h"
 #include "devices/BM4IN1_json.h"
@@ -79,6 +79,7 @@
 #include "devices/BWBSDOO_json.h"
 #include "devices/BM2_json.h"
 #include "devices/ServiceData_json.h"
+#include "devices/JHT_F525_json.h"
 
 const char* _devices[][2] = {
     {_HHCCJCY01HHCC_json, _HHCCJCY01HHCC_json_props},
@@ -94,8 +95,9 @@ const char* _devices[][2] = {
     {_CGDK2_json, _CGDK2_json_props},
     {_CGH1_json, _CGH1_json_props},
     {_JQJCY01YM_json, _JQJCY01YM_json_props},
-    {_IBS_TH1_json, _IBS_TH1_json_props},
-    {_IBS_TH2_json, _IBS_TH2_json_props},
+    {_IBS_THBP01B_json, _IBS_THBP01B_json_props},
+    {_IBT_2X_json_2X, _IBT_2X_json_props},
+    {_IBT_2X_json_2XS, _IBT_2X_json_props},
     {_IBT_4XS_json, _IBT_4XS_json_props},
     {_IBT_6XS_SOLIS6_json, _IBT_6XS_SOLIS6_json_props},
     {_Miband_json, _Miband_json_props},
@@ -115,17 +117,18 @@ const char* _devices[][2] = {
     {_Mokobeacon_json, _Mokobeacon_json_props},
     {_MBXPRO_json, _MBXPRO_json_props},
     {_iNodeEM_json, _iNodeEM_json_props},
-    {_IBT_2X_json, _IBT_2X_json_props},
     {_RuuviTag_RAWv1_json, _RuuviTag_RAWv1_json_props},
     {_RuuviTag_RAWv2_json, _RuuviTag_RAWv2_json_props},
     {_SBCS_json, _SBCS_json_props},
-    {_SBCU_json, _SBCU_json_props},
+    {_SBCU_json_ORIG, _SBCU_json_props},
+    {_SBCU_json_NEW, _SBCU_json_props},
     {_SBMS_json, _SBMS_json_props},
     {_SBMT_json, _SBMT_json_props},
     {_SBS1_json, _SBS1_json_props},
     {_SHT4X_json, _SHT4X_json_props},
     {_SCD4X_json, _SCD4X_json_props},
     {_SmartDry_json, _SmartDry_json_props},
+    {_BC08_json, _BC08_json_props},
     {_BM1IN1_json, _BM1IN1_json_props},
     {_BM3IN1_json, _BM3IN1_json_props},
     {_BM4IN1_json, _BM4IN1_json_props},
@@ -145,4 +148,5 @@ const char* _devices[][2] = {
     {_T301_json, _T301_json_props},
     {_ibeacon_json, _ibeacon_json_props},
     {_ServiceData_json, _ServiceData_json_props},
+    {_JHT_F525_json, _JHT_F525_json_props},
 };
