@@ -1,4 +1,4 @@
-const char* _BM2_json = "{\"brand\":\"GENERIC\",\"model\":\"BM2 Battery Monitor\",\"model_id\":\"BM2\",\"condition\":[\"manufacturerdata\",\"=\",50,\"&\",\"name\",\"index\",0,\"Battery Monitor\"],\"properties\":{\"batt\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",48,2]}}}";
+const char* _BM2_json = "{\"brand\":\"GENERIC\",\"model\":\"BM2 Battery Monitor\",\"model_id\":\"BM2\",\"condition\":[\"manufacturerdata\",\"=\",50,\"&\",\"name\",\"index\",0,\"Battery Monitor\"],\"properties\":{\"batt\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",48,2,false]}}}";
 
 /*R""""(
 {
@@ -8,7 +8,7 @@ const char* _BM2_json = "{\"brand\":\"GENERIC\",\"model\":\"BM2 Battery Monitor\
    "condition":["manufacturerdata", "=", 50, "&", "name", "index", 0, "Battery Monitor"],
    "properties":{
       "batt":{
-         "decoder":["value_from_hex_data", "manufacturerdata", 48, 2]
+         "decoder":["value_from_hex_data", "manufacturerdata", 48, 2, false]
       }
    }
 })"""";*/
