@@ -1,11 +1,11 @@
-const char* _TPMS_json = "{\"brand\":\"GENERIC\",\"model\":\"TPMS\",\"model_id\":\"TPMS\",\"cidc\":false,\"condition\":[\"manufacturerdata\",\"=\",36,\"&\",\"name\",\"index\",0,\"TPMS\"],\"properties\":{\"count\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",5,1,false],\"post_proc\":[\"+\",1]},\"pres\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",16,8,true],\"post_proc\":[\"/\",100000]},\"tempc\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",24,8,true],\"post_proc\":[\"/\",100]},\"batt\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",32,2,true]},\"alarm\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",35,1,false],\"is_bool\":1}}}";
+const char* _TPMS_json = "{\"brand\":\"GENERIC\",\"model\":\"TPMS\",\"model_id\":\"TPMS\",\"cidc\":false,\"condition\":[\"manufacturerdata\",\"=\",36,\"&\",\"manufacturerdata\",\"mac@index\",4],\"properties\":{\"count\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",5,1,false],\"post_proc\":[\"+\",1]},\"pres\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",16,8,true],\"post_proc\":[\"/\",100000]},\"tempc\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",24,8,true],\"post_proc\":[\"/\",100]},\"batt\":{\"decoder\":[\"value_from_hex_data\",\"manufacturerdata\",32,2,true]},\"alarm\":{\"decoder\":[\"bit_static_value\",\"manufacturerdata\",35,0,false,true]}}}";
 /*R""""(
 {
    "brand":"GENERIC",
    "model":"TPMS",
    "model_id":"TPMS",
    "cidc":false,
-   "condition":["manufacturerdata", "=", 36, "&", "name", "index", 0, "TPMS"],
+   "condition":["manufacturerdata", "=", 36, "&", "manufacturerdata", "mac@index", 4],
    "properties":{
       "count":{
          "decoder":["value_from_hex_data", "manufacturerdata", 5, 1, false],
@@ -23,8 +23,7 @@ const char* _TPMS_json = "{\"brand\":\"GENERIC\",\"model\":\"TPMS\",\"model_id\"
          "decoder":["value_from_hex_data", "manufacturerdata", 32, 2, true]
       },
       "alarm":{
-         "decoder":["value_from_hex_data", "manufacturerdata", 35, 1, false],
-         "is_bool":1
+         "decoder":["bit_static_value", "manufacturerdata", 35, 0, false, true]
       }
    }
 })"""";*/
